// CAOS.cpp  --  CAOS command line (Win32 console)
// Copyright (C) 2001 by Mirality Systems

#define WIN32_LEAN_AND_MEAN
#define STRICT
#include <windows.h>
#include <iostream.h>
#include <iomanip.h>
#include <string>
#include "c3engine.h"

PCreaturesEngine engine;

BOOL WINAPI ConsoleHandler(DWORD) {
	// Any signal received here means that we want to bail.
	cout << endl << "Terminating connection." << endl;
	CreaturesDisconnect(&engine);
	return FALSE;
}

int main() {
	char game[24];
	
	cout << "Mirality CAOS Command Line for Win32" << endl;
	
	// Try to load game engine
	CreaturesLastGame(game, 24);
	cout << "Trying to connect to " << game << "..." << endl;
	DWORD result = CreaturesConnect(game, &engine);
	if(result == CREATURES_SUCCESS) {
		cout << "Connected to engine.  Press CTRL-Break to exit." << endl << endl;
		SetConsoleCtrlHandler(ConsoleHandler, TRUE);
		
		for(;;) {
			string cmd;
			
			cout << "> ";
			getline(cin, cmd);

			if((result = CreaturesExecute(engine, cmd.c_str())) != CREATURES_SUCCESS) {
				// Unsuccessful execution
				cout << "Execution failed (code " << result << ')' << endl;
			}
			DWORD size = CreaturesResult(engine, NULL, 0);
			LPBYTE buffer = new BYTE[size];
			CreaturesResult(engine, buffer, size);
			// Before display, convert '\r's into '\n's, so they show correctly in
			// the console window
			for(char *p=buffer; *p; ++p) if(*p == '\r') *p = '\n';
			cout << buffer << endl;
			delete[] buffer;
		}
	} else {
		cout << "Failed to connect to " << game << " engine, result code " << result << endl;
	}
	CreaturesDisconnect(&engine);
	return 1;
}
